#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoogle
version:              5.0.18.4
visibility:           public
id:                   hoogle-5.0.18.4-4wXmJS5YiV3RTI0pi0rvV
key:                  hoogle-5.0.18.4-4wXmJS5YiV3RTI0pi0rvV
license:              BSD-3-Clause
copyright:            Neil Mitchell 2004-2024
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://hoogle.haskell.org/
synopsis:             Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.

category:             Development
abi:                  86cc4982b67e1167803a0df6ce5ec4f6
exposed:              True
exposed-modules:      Hoogle
hidden-modules:
    Paths_hoogle Action.CmdLine Action.Generate Action.Search
    Action.Server Action.Test Input.Cabal Input.Download Input.Haddock
    Input.Item Input.Reorder Input.Set Input.Settings Output.Items
    Output.Names Output.Tags Output.Types Query General.Conduit
    General.IString General.Log General.Store General.Str
    General.Template General.Timing General.Util General.Web

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hoogle
hs-libraries:         HShoogle-5.0.18.4-4wXmJS5YiV3RTI0pi0rvV
include-dirs:         /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4/include
includes:             include.h
depends:
    QuickCheck-2.15.0.1-IEDVvHXQ1Jd7OqAH4jP2Br
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT base-4.18.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-3zJbEruN1MK4AfSPvaGc85
    blaze-markup-0.8.3.0-DDuKg87sJ0pLWg6HCDFYiH bytestring-0.11.5.3
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-Cq9iqjolcw6I0oNouBZzAG
    conduit-extra-1.3.8-9gSM61pV2WFG1rnKdBHlFQ containers-0.6.7
    crypton-connection-0.4.5-5tDmWt03tatIxT3297Y0tD deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-5TJRL61mQdJ37nJ79jr8U
    filepath-1.4.300.1 foundation-0.0.30-6skbgXTSSMQ6lxsCo3UqmT
    hashable-1.4.7.0-AuDVFqXH7XaG9xiVOVTNBi
    haskell-src-exts-1.23.1-7kjB9e0U60xHvvVg6eyq06
    http-conduit-2.3.9.1-DP2lFgSMOheFQZhXqyYPv7
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    js-flot-0.8.3-CSwWF2xMOrpIfADJpYok8C
    js-jquery-3.7.1-LXnsbJ3Ij0mH73JlDSHQQv
    mmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    process-extras-0.7.4-9rxfUTw6ZqzB6UPz9TluPV
    resourcet-1.2.6-52ownTUzBgaCUPB29DeWym
    safe-0.3.21-Ki9XWKg9cP9KpwzlIW2n9t
    storable-tuple-0.1-FdlAY9MSBdS5r3Yw6NK2mW
    tar-0.6.0.0-2jrfSWv0wgbrIC8tDfkFC template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    uniplate-1.6.13-7y3rluGnYuPKDSppbqd6yK
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI
    wai-3.2.4-JKCq5JcGzi0CtrYAeT794h
    wai-logger-2.5.0-FoEyiLq9IHY402T4GO6Ovh
    warp-3.4.0-46pmJiGox9pGiGB1xG7SW0
    warp-tls-3.4.9-6240oSEZqWA7qAolGXfrLB
    zlib-0.7.1.0-5Rjzs1QvYLu4tPh1e1fSOv

haddock-interfaces:   /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html:         /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

